Cheetah.Servlet module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.Servlet module

Provides an abstract Servlet baseclass for Cheetah’s Template class

class `Cheetah.Servlet.` `Servlet`

  Bases: `object`

  This class is an abstract baseclass for Cheetah.Template.Template.

  `application` = None
  `request` = None
  `respond`(trans=None)
  `serverSidePath`(path=None, normpath=<function normpath>, abspath=<function abspath>)
  `session` = None
  `shutdown`()
  `sleep`(transaction)
  `transaction` = None